@@ -5,6 +5,7 @@ from __future__ import absolute_import, division, print_function
 
 import itertools
 import operator
+import warnings
 
 import pytest
 
@@ -16,8 +17,7 @@ from packaging.specifiers import (
 )
 from packaging.version import LegacyVersion, Version, parse
 
-from .test_version import VERSIONS, LEGACY_VERSIONS
-
+from .test_version import LEGACY_VERSIONS, VERSIONS
 
 LEGACY_SPECIFIERS = [
     "==2.1.0.3",
@@ -253,6 +253,12 @@ class TestSpecifier:
         assert op(left, Specifier(right))
         assert op(Specifier(left), right)
 
+    @pytest.mark.parametrize(("left", "right"), [("==2.8.0", "==2.8")])
+    def test_comparison_canonicalizes(self, left, right):
+        assert Specifier(left) == Specifier(right)
+        assert left == Specifier(right)
+        assert Specifier(left) == right
+
     @pytest.mark.parametrize(
         ("left", "right", "op"),
         itertools.chain(
@@ -626,6 +632,12 @@ class TestSpecifier:
 
 
 class TestLegacySpecifier:
+    def test_legacy_specifier_is_deprecated(self):
+        with warnings.catch_warnings(record=True) as w:
+            LegacySpecifier(">=some-legacy-version")
+            assert len(w) == 1
+            assert issubclass(w[0].category, DeprecationWarning)
+
     @pytest.mark.parametrize(
         ("version", "spec", "expected"),
         [
@@ -961,6 +973,26 @@ class TestSpecifierSet:
         assert not op(left, SpecifierSet(right))
         assert not op(SpecifierSet(left), right)
 
+    @pytest.mark.parametrize(("left", "right"), [("==2.8.0", "==2.8")])
+    def test_comparison_canonicalizes(self, left, right):
+        assert SpecifierSet(left) == SpecifierSet(right)
+        assert left == SpecifierSet(right)
+        assert SpecifierSet(left) == right
+
     def test_comparison_non_specifier(self):
         assert SpecifierSet("==1.0") != 12
         assert not SpecifierSet("==1.0") == 12
+
+    @pytest.mark.parametrize(
+        ("version", "specifier", "expected"),
+        [
+            ("1.0.0+local", "==1.0.0", True),
+            ("1.0.0+local", "!=1.0.0", False),
+            ("1.0.0+local", "<=1.0.0", True),
+            ("1.0.0+local", ">=1.0.0", True),
+            ("1.0.0+local", "<1.0.0", False),
+            ("1.0.0+local", ">1.0.0", False),
+        ],
+    )
+    def test_comparison_ignores_local(self, version, specifier, expected):
+        assert (Version(version) in SpecifierSet(specifier)) == expected
