@@ -5,11 +5,12 @@ from __future__ import absolute_import, division, print_function
 
 import itertools
 import operator
+import warnings
 
 import pretend
 import pytest
 
-from packaging.version import Version, LegacyVersion, InvalidVersion, parse
+from packaging.version import InvalidVersion, LegacyVersion, Version, parse
 
 
 @pytest.mark.parametrize(
@@ -748,6 +749,11 @@ class TestVersion:
     def test_comparison_false(self, left, right, op):
         assert not op(Version(left), Version(right))
 
+    @pytest.mark.parametrize("op", ["lt", "le", "eq", "ge", "gt", "ne"])
+    def test_dunder_op_returns_notimplemented(self, op):
+        method = getattr(Version, "__{0}__".format(op))
+        assert method(Version("1"), 1) is NotImplemented
+
     @pytest.mark.parametrize(("op", "expected"), [("eq", False), ("ne", True)])
     def test_compare_other(self, op, expected):
         other = pretend.stub(**{"__{0}__".format(op): lambda other: NotImplemented})
@@ -758,11 +764,29 @@ class TestVersion:
         result = sorted([Version("0"), LegacyVersion("1")])
         assert result == [LegacyVersion("1"), Version("0")]
 
+    def test_major_version(self):
+        assert Version("2.1.0").major == 2
+
+    def test_minor_version(self):
+        assert Version("2.1.0").minor == 1
+        assert Version("2").minor == 0
+
+    def test_micro_version(self):
+        assert Version("2.1.3").micro == 3
+        assert Version("2.1").micro == 0
+        assert Version("2").micro == 0
+
 
 LEGACY_VERSIONS = ["foobar", "a cat is fine too", "lolwut", "1-0", "2.0-a1"]
 
 
 class TestLegacyVersion:
+    def test_legacy_version_is_deprecated(self):
+        with warnings.catch_warnings(record=True) as w:
+            LegacyVersion("some-legacy-version")
+            assert len(w) == 1
+            assert issubclass(w[0].category, DeprecationWarning)
+
     @pytest.mark.parametrize("version", VERSIONS + LEGACY_VERSIONS)
     def test_valid_legacy_versions(self, version):
         LegacyVersion(version)
@@ -869,6 +893,11 @@ class TestLegacyVersion:
     def test_comparison_false(self, left, right, op):
         assert not op(LegacyVersion(left), LegacyVersion(right))
 
+    @pytest.mark.parametrize("op", ["lt", "le", "eq", "ge", "gt", "ne"])
+    def test_dunder_op_returns_notimplemented(self, op):
+        method = getattr(LegacyVersion, "__{0}__".format(op))
+        assert method(LegacyVersion("1"), 1) is NotImplemented
+
     @pytest.mark.parametrize(("op", "expected"), [("eq", False), ("ne", True)])
     def test_compare_other(self, op, expected):
         other = pretend.stub(**{"__{0}__".format(op): lambda other: NotImplemented})
